@@ -9,7 +9,12 @@
 # You should have received a copy of the GNU General Public License along with seacarb; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 "pCa" <- function(flag,  var1,  var2, Ca, S=35, T=20, P=0, Pt=0, Sit=0, k1k2='x', kf='x', ks="d", pHscale="T", b="l10"){
-	ci <- carb(flag, var1= var1, var2= var2, S=S ,T=T, P=P, Pt=Pt, Sit=Sit, k1k2=k1k2, kf=kf, ks="d", pHscale=pHscale, b=b) # initial carbonate chemistry
+  # if the concentrations of total silicate and total phosphate are NA
+  # they are set at 0
+  Sit[is.na(Sit)] <- 0
+  Pt[is.na(Pt)] <- 0
+  
+  ci <- carb(flag, var1= var1, var2= var2, S=S ,T=T, P=P, Pt=Pt, Sit=Sit, k1k2=k1k2, kf=kf, ks="d", pHscale=pHscale, b=b) # initial carbonate chemistry
 	#0.01028*(S/35) # calcium concentration (Dickson et al., 2007)
 	#co <- ci
 	#if (length(Ca) > 1) {for(i in 1:(length(Ca)-1)) {co <- rbind(co,c)}}
