@@ -10,7 +10,12 @@
 #
 "pmix" <-
 function(flag, var1, var2, pCO2s, wf, S=35, T=20, P=0, Pt=0, Sit=0, k1k2='x', kf='x', ks="d", pHscale="T", b="l10"){
-	sys <- 0
+  # if the concentrations of total silicate and total phosphate are NA
+  # they are set at 0
+  Sit[is.na(Sit)] <- 0
+  Pt[is.na(Pt)] <- 0
+  
+  sys <- 0
 	if (sys==0) {
 		ws <- 1 * wf
 		wi <- 1 - ws
