@@ -10,7 +10,12 @@
 #
 "psi" <-
 function(flag, var1, var2, S=35, T=20, P=0, Pt=0, Sit=0, pHscale="T", kf="x", k1k2="x", ks="d"){
-		buf <- buffer(flag=flag, var1=var1, var2=var2, S=S, T=T, P=P, Pt=Pt, Sit=Sit, pHscale=pHscale, kf=kf, k1k2=k1k2, ks=ks)
+  # if the concentrations of total silicate and total phosphate are NA
+  # they are set at 0
+  Sit[is.na(Sit)] <- 0
+  Pt[is.na(Pt)] <- 0
+  
+  buf <- buffer(flag=flag, var1=var1, var2=var2, S=S, T=T, P=P, Pt=Pt, Sit=Sit, pHscale=pHscale, kf=kf, k1k2=k1k2, ks=ks)
 		psi <- -buf$PiC/buf$PiD
 out <- psi
 attr(out,"unit") <- "mol CO2/mol CaCO3"
